
* Aggregate Dynamics in Lumpy Economies
* by Isaac Baley and Andres Blanco
* ECONOMETRICA, 2020

/* This code produces Figure 3: Empirical Distribution of Non-Zero Capital Gap Changes

 - Reads directly the clean data that contains a panel of observables (Delta x, tau)
 
 - Specifications: 
	.... Chilean Annual Industrial Survey (ENIA) 
	.... Firms with more than 10 years of data
	.... Only one stopping time per firm
	.... All firm sizes
	.... All sectors
	.... Without firm weights
	.... Eliminates outliers above 98th and below 2nd percentile
	.... Inaction threshold of 1%
	.... Non-zero gap changes
	
 - Splits the distribution of Delta x for durations below and above their average
 
 - Saves the data for the figure on a .csv file 
 
*/

* Panel data of (Delta x, tau) for structures
qui use "Balance_tau1_Sampleall_Sectorall_weightno_build_outliers2.dta", clear

qui sum tau
local  mean_tau=r(mean)
replace Delta_x=1.5 if Delta_x>=1.5
replace Delta_x=-0.5 if Delta_x<=-0.5

preserve  
twoway__histogram_gen Delta_x if (tau<`mean_tau'), start(-0.3) width(0.05) fraction gen(freq_build_lEt bin, replace)
keep if freq_build_lEt != . 
keep freq_build_lEt bin 
save "Histogram_Deltax_buil_belowavgdur.dta", replace 
restore

preserve  
twoway__histogram_gen Delta_x if (tau>=`mean_tau'), start(-0.3) width(0.05) fraction gen(freq_build_mEt bin, replace)
keep if freq_build_mEt != . 
keep freq_build_mEt bin 
save "Histogram_Deltax_buil_aboveavgdur.dta", replace 
restore
  
* Panel data of  (Delta x, tau) for total capital
qui use "Balance_tau1_Sampleall_Sectorall_weightno_total_outliers2.dta", clear
qui sum tau
local  mean_tau=r(mean)
replace Delta_x=1.5 if Delta_x>=1.5
replace Delta_x=-0.5 if Delta_x<=-0.5

preserve  
twoway__histogram_gen Delta_x if (tau<`mean_tau'), start(-0.3) width(0.05) fraction gen(freq_all_lEt bin, replace)
keep if freq_all_lEt != . 
keep freq_all_lEt bin 
save "Histogram_Deltax_total_belowavgdur.dta", replace 
restore

preserve  
twoway__histogram_gen Delta_x if (tau>=`mean_tau'), start(-0.3) width(0.05) fraction gen(freq_all_mEt bin, replace)
keep if freq_all_mEt != . 
keep freq_all_mEt bin 
save "Histogram_Deltax_total_aboveavgdur.dta", replace 
restore

* Merge datasets
use "Histogram_Deltax_buil_belowavgdur.dta", clear
merge 1:1 bin using "Histogram_Deltax_buil_aboveavgdur.dta"
drop _merge
merge 1:1 bin using "Histogram_Deltax_total_belowavgdur.dta"
drop _merge
merge 1:1 bin using "Histogram_Deltax_total_aboveavgdur.dta"
drop _merge

export delimited "Histogram_investments.csv", replace 
