%{
Aggregate Dynamics in Lumpy Economies
by Isaac Baley and Andres Blanco
ECONOMETRICA, 2020

This script writes the .tex file for Table I, 
using output from the Stata program TableI.do

%}


%% Load data from Excel files

% Preallocate arrays
Data_load_m = zeros(23,2);
Data_CK     = zeros(4,2);

% Read data from Excel tables
% Main statistics
Data_load_m(:,1)  =xlsread('Formula_Balance_tau1_Sampleall_weightno_Sectorall_build_outliers2.xlsx',1,'B2:B25');
Data_load_m(:,2)  =xlsread('Formula_Balance_tau1_Sampleall_weightno_Sectorall_total_outliers2.xlsx',1,'B2:B25');
% Kurtosis and CIRs
Data_CK(:,1)      = xlsread('Formula_Balance_tau1_Sampleall_weightno_Sectorall_build_outliers2.xlsx',1,'E33:E36');
Data_CK(:,2)      = xlsread('Formula_Balance_tau1_Sampleall_weightno_Sectorall_total_outliers2.xlsx',1,'E33:E36');

% Rearrange data matrices
Data_load_m = [Data_load_m(1,:);                                           %1 E[tau]
               Data_load_m(4:9,:);                                         %2 CV[tau], 3 E[Dx], 4 E[Dx^2], 5 Cov(Dx,tau), 6 E[(x^*-D x)^3], 7 E[tau(x^d-Dx)^2]
               Data_load_m(12:19,:);                                       %8 nu  9 sigma^2  10 x^*  11 V[x]  12 Cov[a,x] 13 M2/sigma^2 14 -nu*M11[a,x]/sigma^2 16 CIR[x]
               Data_load_m(23,:)];                                         %17 E[a]
Data_load_m(5:6,:) = flipud(Data_load_m(5:6,:));                           %5 E[(x^*-D x)^3] 6 Cov(Dx,tau)
Data_load_m = [Data_load_m(1:11,:);Data_load_m(16,:);Data_load_m(12:end-1,:)];

% Define row labels for inputs from data
Statistics_data    ={'$\\bE[\\tau]$';'$\\bCV^2[\\tau]$';'';'$\\bE[\\Delta x]$';...
                '$\\bE[\\Delta x^2]$ ';'$\\bE[(x_{\\tau}^3]$ ';...
                '\\bK[\\Delta x]';'$\\bCov[\\tilde{\\tau},\\Delta x]$ ';...
                '$\\bE[\\tilde{\\tau} x_{\\tau}^2]$'};

% Define row labels for outputs from theory
Statistics_theory  ={'$\\nu$ ';'$\\sigma^2$ ';'$x^{\\ast}$';...
                '$\\V[x]$ ' ;'$\\Cov[a,x]$ ';'$\\E[a]$ ';'';...
                'Drift + Asymmetric';'Driftless + Symmetric'};
            
% Select inputs from data from main array of statistics
Data_load_m_data=Data_load_m(1:7,:);
Data_load_m_data=[Data_load_m_data(1:2,:);-1000*ones(1,2);Data_load_m_data(3:5,:); Data_CK(1,:); 
                  Data_load_m_data(6:end,:)./Data_load_m(1,:)];            %6 Cov(Dx,\tilde{tau}), 7 E[\tilde{tau}(x^d-Dx)^2], normalized by E[tau]
% Select outputs from theory from main array of statistics
Data_load_m(12:13,:) = flipud(Data_load_m(12:13,:));
Data_load_m_theory=[Data_load_m(8:13,:); -1000*ones(1,2) ; Data_load_m(16,:); Data_CK(3,:)];

  
%% Print table in LaTeX code

fid=fopen('tableI_inputsoutputs.tex','w+');

fprintf(fid,'\\begin{table}[h]\n');
fprintf(fid,'\\centering \n');
fprintf(fid,'\\begin{threeparttable} \n');
fprintf(fid,'\\footnotesize \n');
fprintf(fid,'\\caption{Inputs from Micro Data and Outputs from the Theory  \\label{main:tab:FormulaChileBalance}} \n');
fprintf(fid,'\\begin{tabular}{l    c c  c l c c   } \n');
fprintf(fid,' \\\\ \n');
fprintf(fid,' & \\multicolumn{2}{c }{\\textbf{Inputs from Data}} &&& \\multicolumn{2}{c }{\\textbf{\\textbf{Outputs from Theory}}} \\\\ [.2cm] \n');
fprintf(fid,'  & \\textbf{Structures} &   \\textbf{Total}  & && \\textbf{Structures} &   \\textbf{Total}      \\\\  \\hline  \\hline \n');
fprintf(fid,'%% \n');

for jj=1:size(Statistics_data,1)

    % After certain rows, print headers
    if jj==1 
        fprintf(fid,'\\multicolumn{3}{l }{  \\textbf{Duration}}&& \\multicolumn{3}{l }{ \\textbf{Parameters} }  \\\\ \\cline{1-3} \\cline{5-7} \n');
        fprintf(fid,'%% \n');
    end

    if jj==4 
        fprintf(fid,' \\cline{1-3} \\cline{5-7} \n');
        fprintf(fid,'%% \n');
        fprintf(fid,' \\multicolumn{3}{l }{ \\textbf{Gap Changes}}&&\\multicolumn{3}{l }{  \\textbf{Sufficient Statistics}}  \\\\ \\cline{1-3} \\cline{5-7}  \n');
        fprintf(fid,'%% \n');
    end

    if jj==8
        fprintf(fid,' \\cline{1-3} \\cline{5-7} \n');
        fprintf(fid,'%% \n');
        fprintf(fid,' \\multicolumn{3}{l }{ \\textbf{Covariances}}&& \\multicolumn{3}{l }{    \\textbf{CIR$_1$} } \\\\ \\cline{1-3} \\cline{5-7} \n');
        fprintf(fid,'%% \n');
    end

    % Print row labels for inputs from data
    fprintf(fid,Statistics_data{jj,1});

    % Print numerical values for inputs from data
    for ii=1:size(Data_load_m_data,2)
        if Data_load_m_data(jj,ii)==-1000
            fprintf(fid,strcat('& '));
        else
            fprintf(fid,strcat('& ',num2str(Data_load_m_data(jj,ii),'%5.3f')));
        end
    end

    fprintf(fid,strcat('&& '));

    % Print row labels for outputs from theory
    fprintf(fid,Statistics_theory{jj,1});

    % Print numerical values for outputs from theory
    for ii=1:size(Data_load_m_theory,2)
        if Data_load_m_theory(jj,ii)==-1000
            fprintf(fid,strcat('& '));
        else
            fprintf(fid,strcat('& ',num2str(Data_load_m_theory(jj,ii),'%5.3f')));
        end
    end
       fprintf(fid,'\\\\  \n');
end

% Rest of the file
fprintf(fid,'\\hline \\hline\n');
fprintf(fid,'\\end{tabular} \n');
fprintf(fid,'\\justify \n');
fprintf(fid,'{\\footnotesize  \n');
fprintf(fid,'Notes: Own calculations using establishment-level  data from Chile. Sample: Firms with at least 10 years of data, truncation at 2nd and 98th percentiles, and inaction threshold of $\\underline{i} = 0.01$. Gap of adjusters: $x_{\\tau} = x^{\\ast} - \\Delta x$. Normalized duration: $\\tilde{\\tau} \\equiv \\tau/\\bE[\\tau]$.}\n');
fprintf(fid,'\\end{threeparttable}  \n');
fprintf(fid,'\\end{table} \n');
fclose(fid);

