* Main file for producing statistics and figures from harmonized data
* Modified for generating Table I
* by Isaac Baley and Andres Blanco

* Panel data of investment, capital stocks and deflators
qui use "CHILE_CLEAN_PIM.dta", clear

* Declare panel 
xtset id year
sort  id year
order id year

* Turn globals into locals
local  file          ="$fileg"

local  Tauclean		 = $Tauclean
local  CapitalType   ="$CapitalType"
local  FirmType      ="$FirmType"
local  WeightFirm    ="$WeightFirm"
local  SectorType    ="$SectorType"

* Inaction thresholds
local  lb_cut        =-0.01
local  up_cut        =0.01

* Compute the raw data
local  filename = "Formula_Balance_tau`Tauclean'_Sample`FirmType'_weight`WeightFirm'_Sector`SectorType'_`CapitalType'_outliers${outliers}"
else qui putexcel set "`filename'.xlsx", sheet("RawMoments") replace

* Define dummy for firms with more than 10 years of data
qui bys id:gen total_obs=_N
qui sum total_obs
qui gen dummy_bal=0
qui replace dummy_bal=1 if total_obs>=$years_da	
qui drop total_obs

* Insert labels in Excel file
qui putexcel A2  =("Inputs Data")
qui putexcel A3  =("m1(tau)")
qui putexcel A4  =("m2(tau)")
qui putexcel A5  =("Std(tau)")
qui putexcel A6  =("CV2(tau)")
qui putexcel A7  =("m1(Dx)")
qui putexcel A8  =("m2(Dx)")
qui putexcel A9  =("Cov(Dx,tau)")
qui putexcel A10 =("E(h x-D x)^3")
qui putexcel A11 =("Etau (h x-D x)^2")

qui putexcel A13 =("Output theory")
qui putexcel A14 =("nu")
qui putexcel A15 =("sigma^2")
qui putexcel A16 =("hat x")
qui putexcel A17 =("M2[x]")
qui putexcel A18 =("M11[a,x]")
qui putexcel A19 =("M2/sigma^2")
qui putexcel A20 =("-nu*M11[a,x]/sigma^2")
qui putexcel A21 =("A1[x]")

qui putexcel A23 =("Cross-Checks")
qui putexcel A24 =("mean tau")
qui putexcel A25 =("Average Age with tau")
qui putexcel A26 =("Inverse Frequency")
qui putexcel A27 =("Average Age")

qui putexcel B2 =("mean")
qui putexcel C2 =("p10")
qui putexcel D2 =("p50")
qui putexcel E2 =("p90")

qui putexcel D33 =("Centralized Kur.")
qui putexcel D34 =("No-Centralized Kur.")
qui putexcel D35 =("CIR CK")
qui putexcel D36 =("CIR NCK")
qui putexcel E32 =("mean")
qui putexcel F32 =("p10")
qui putexcel G32 =("p50")
qui putexcel H32 =("p90")

qui putexcel A31 =("Options in the code")
qui putexcel A32 =("Balance")
qui putexcel A33 =("Outliers")
qui putexcel A34 =("Right Truncation Tau")
qui putexcel A35 =("lower truncation")
qui putexcel A36 =("upper truncation")
qui putexcel A37 =("Depresiation")
qui putexcel A38 =("Weighted sample")
qui putexcel A39 =("Sectors")
qui putexcel A40 =("Firms")

* Save options
qui putexcel B32 =($balance_panel)
qui putexcel B33 =($outliers)
qui putexcel B34 =($Tauclean)
qui putexcel B35 =(`lb_cut')
qui putexcel B36 =(`up_cut')


* Generate Delta x and the dummy for outliers

if "`CapitalType'"=="build" {

	gen inv_rate=inv_stru/Def_k_buil/l.capitalPIM_stru if l.capitalPIM_stru~=0 
	qui putexcel C1 =("Buildings")
	gen K_type =capitalPIM_stru
}
if "`CapitalType'"=="mach" {

	gen inv_rate=inv_mach/Def_k_mach/l.capitalPIM_mach if l.capitalPIM_mach~=0 
	qui putexcel C1 =("Machines")
	gen K_type =capitalPIM_mach
	
}
if "`CapitalType'"=="vehi" {

	gen inv_rate=inv_vehi/Def_k_vehi/l.capitalPIM_vehi if l.capitalPIM_vehi~=0 
	qui putexcel C1 =("Vehicles")
	gen K_type =capitalPIM_vehi
}
if "`CapitalType'"=="total" {

	gen inv_rate=inv_total/l.capitalPIM_total if l.capitalPIM_total~=0 
	qui putexcel C1 =("Total")
	gen K_type =capitalPIM_total
	
}
*

* Generate firm weights
if "`WeightFirm'"=="yes" {
	
	sort year
	by year: egen total_K=sum(K_type) if dummy_bal==1
	gen weight_aux=K_type/total_K*100
	sort id year
	by id: egen weight=mean(weight_aux)
	drop weight_aux
	qui putexcel B38 =("yes")	
	
}
else if "`WeightFirm'"=="no" {

	gen weight=1
	qui putexcel B38 =("no")	
}
*

* Choose sample by firm size
if "`FirmType'"=="all"{

	qui putexcel B40 =("All firms")

}
else if "`FirmType'"=="small" | "`FirmType'"=="medium" | "`FirmType'"=="large" | "`FirmType'"=="extralarge"{

	* Obtain firm fixed effects for log employment
	sort id year
	gen l_labor=ln(labor)
	xtreg l_labor year, fe
	predict ff_hat, u
	drop l_labor

	* Compute firm weight = average capital (of considered type)
	sort year
	by year: egen total_K=sum(K_type) if dummy_bal==1
	gen weight_aux=K_type/total_K*100
	sort id year
	by id: egen weight_aux2=mean(weight_aux)
	drop weight_aux 
	
	* Compute firm size based on percentiles of (weighted) log labor fixed effects
	sum ff_hat if dummy_bal==1 [w=weight_aux2]  ,d
	local per25=`r(p25)'
	local per50=`r(p50)'
	local per75=`r(p75)'

	gen var_aux=.
	replace var_aux=1 				      if ff_hat~=. &                   ff_hat<=`per25'  &  dummy_bal==1
	replace var_aux=2  					  if ff_hat~=. & ff_hat> `per25' & ff_hat<= `per50' &  dummy_bal==1
	replace var_aux=3  					  if ff_hat~=. & ff_hat> `per50' & ff_hat<= `per75' &  dummy_bal==1
	replace var_aux=4  					  if ff_hat~=. & ff_hat> `per75' 					&  dummy_bal==1
 
	by id: egen dummy_labor=mean(var_aux)
	drop var_aux ff_hat
	 
	* Save weights of each firm type
	preserve
	
	replace K_type=. if dummy_bal~=1
	collapse (sum) K_type, by(year dummy_labor) 
	sort year dummy_labor
	by year: egen total_K=sum(K_type) 
	gen weight_F     =K_type/total_K*100
	collapse (mean) weight_F, by(dummy_labor) 
	
	if "`FirmType'"=="small" {
		sum weight_F if dummy_labor == 2
	}
	else if "`FirmType'"=="medium" {	
		sum weight_F if dummy_labor == 2
	}
	else if  "`FirmType'"=="large" {	
		sum weight_F if dummy_labor == 3
	}
	else if  "`FirmType'"=="extralarge"{	
		sum weight_F if dummy_labor == 4
	}
	qui putexcel A29 =("Weight `FirmType'")
	qui putexcel B29 =(`r(mean)')
	
	restore	
	
	* Select sample
	if "`FirmType'"=="small" {
		keep if dummy_labor==1 
		qui putexcel B40 =("Small firms")
	}
	else if "`FirmType'"=="medium" {	
		keep if dummy_labor==2 
		qui putexcel B40 =("medium firms")
	}
	else if  "`FirmType'"=="large" {	
		keep if dummy_labor==3
		qui putexcel B40 =("large firms")		
	}
	else if  "`FirmType'"=="extralarge"{	
		keep if dummy_labor==4
		qui putexcel B40 =("extralarge firms")	
	}
	
	drop dummy_labor weight_aux2

}

*

* Select sample by sector
if "`SectorType'"=="all" {
	
	qui putexcel B39 =("All")
	
}
else if "`SectorType'"=="subset" {

	drop if sector==2 & sector==5 
	qui putexcel B39 =("All minus 2 and 5")
	
}
else if inlist("`SectorType'", "1","2","3","4","5","6","7","8") {
	 
	* Save sector weights
	preserve
	
	replace K_type=. if dummy_bal~=1
	collapse (sum) K_type, by(year sector) 
	sort year sector
	by year: egen total_K=sum(K_type) 
	gen weight_S     =K_type/total_K*100
	collapse (mean) weight_S, by(sector) 
 	sum weight_S if sector == `SectorType'
	
	qui putexcel A29 =("Weight `SectorType'")
	qui putexcel B29 =(`r(mean)')
	
	restore
	 
	keep if sector == `SectorType'
	qui putexcel B39 =(`SectorType')
}
*

* Drop outliers (trim tails of investment rate distribution)
if $outliers >=1{
		
		qui gen dummy_out=1 if inv_rate~=. & dummy_bal==1
		qui replace dummy_out=0 if inv_rate~=. & dummy_bal==1 & inv_rate<=-1
		
		qui sum inv_rate if inv_rate~=. & dummy_bal==1 & dummy_out==1 [w=weight],d 

		qui replace dummy_out=0 if inv_rate<r(p1)  & inv_rate~=. & dummy_bal==1 & dummy_out==1 /*r(p1) */
		qui replace dummy_out=0 if inv_rate>r(p99) & inv_rate~=. & dummy_bal==1 & dummy_out==1

		if $outliers >=2{

			qui sum inv_rate if inv_rate~=. & dummy_bal==1 & dummy_out==1 [w=weight],d

			qui replace dummy_out=0 if inv_rate<r(p1)  & inv_rate~=. & dummy_bal==1 & dummy_out==1
			qui replace dummy_out=0 if inv_rate>r(p99) & inv_rate~=. & dummy_bal==1 & dummy_out==1

		}
}
*	

* Compute Delta x
gen Delta_x = ln(1+inv_rate) if dummy_out==1 & dummy_bal==1

* Generate stopping times
by id: gen counter=_n

gen freq_inac = (inv_rate<`lb_cut' | inv_rate>`up_cut' ) & Delta_x!=. // inaction indicator
 
replace freq_inac     =. if freq_inac==0
by id: egen first_inv =min(counter*freq_inac)
by id: egen last_inv  =max(counter*freq_inac)
replace freq_inac     =0 if freq_inac==.

* Drop right and left truncation
gen tau=1 if counter> first_inv & counter<=last_inv 
by id: replace tau=l.tau+1 if l.freq_inac==0  
gen age=tau
replace tau=. if freq_inac==0
drop first_inv last_inv counter 

* Cross-verification 
*qui sum freq_inac if dummy_bal==1 & dummy_out==1 & year>=2000 [w=weight], d
qui sum freq_inac if dummy_bal==1 & dummy_out==1 [w=weight], d
local  var_aux=1/r(mean)
qui putexcel B26=(`var_aux')
*qui sum age if dummy_bal==1 & dummy_out==1 & year>=2000 [w=weight], d
qui sum age if dummy_bal==1 & dummy_out==1 [w=weight], d
local  var_aux=r(mean)
qui putexcel B27=(`var_aux')


* Compute statistics for a random selection of stopping times
foreach index_i of numlist 1/50{ // repeat computations 50 times, saving results
	
	local dis_par=`index_i' 

	*display "`dis_par'"
	
	*qui putexcel `=char(`index_i')'2=`index_i'-66
	
	* Generate dummies for unique stopping times
	if $Tauclean ==1 {	
	
	qui gen dummy_tau=0
	
	* Keep only one random stopping per firm
	qui gen u1 = runiform() if tau~=.
	qui by id: egen u2_max=max(u1)
	qui replace dummy_tau=1 if u1>u2_max-0.00000000001 & tau~=.

	drop u1 u2_max	
	
	}
	
	* Keep all stopping times
	else if $Tauclean ==0{

		gen dummy_tau=1
		
	}
	* 
	
	* Save data for computing the histograms
	preserve
		
		if `index_i'==1{
		
			qui keep if dummy_tau==1 & dummy_bal==1 & dummy_out==1
			qui keep Delta_x tau 
			qui save "Balance`balance_panel'_tau`Tauclean'_Sample`FirmType'_Sector`SectorType'_weight`WeightFirm'_`CapitalType'_outliers${outliers}.dta", replace
		
		}
		else if `index_i'>1{
			qui keep if dummy_tau==1 & dummy_bal==1 & dummy_out==1
			qui keep Delta_x tau 
		
			qui append using "Balance`balance_panel'_tau`Tauclean'_Sample`FirmType'_Sector`SectorType'_weight`WeightFirm'_`CapitalType'_outliers${outliers}.dta"
			qui save "Balance`balance_panel'_tau`Tauclean'_Sample`FirmType'_Sector`SectorType'_weight`WeightFirm'_`CapitalType'_outliers${outliers}.dta", replace
			
		}
		
	restore
		 
	* --- INPUTS FROM DATA / OUTPUTS FROM THEORY ---
		 
	* Moments of the stopping time distribution
	qui  sum tau if dummy_tau==1 & dummy_bal==1 & dummy_out==1 [w=weight] , d
	local  mean_tau=r(mean)				// E[tau]
	matrix col_n= [`mean_tau']
	local  var_aux=r(Var)+r(mean)^2		// E[tau^2]
	matrix col_n= [col_n, `var_aux']
	local  var_aux=r(Var)^0.5			// sd[tau]
	matrix col_n= [col_n, `var_aux']
	local  CV_tau=r(Var)/r(mean)^2		// CV^2[tau]
	matrix col_n= [col_n, `CV_tau']

	local var_aux_check1 =r(mean)
	local var_aux_check2 =`mean_tau'/2*(1+`CV_tau')
	
	* Moments of the distribution of capital gap changes
	qui sum Delta_x if dummy_tau==1 & dummy_bal==1 & dummy_out==1 [w=weight], d
	local  mean_Dx=r(mean)				// E[\Delta x]
	matrix col_n= [col_n, `mean_Dx']
	local  m2_Dx=r(Var)+r(mean)^2		// E[\Delta x^2]
	matrix col_n= [col_n, `m2_Dx']
	local  Kur_Dx_c=r(kurtosis)			// Kur[\Delta x] - centralized
	
	* Non-centralized kurtosis
	qui gen var_aux= Delta_x^2
	qui sum var_aux if dummy_tau==1 & dummy_bal==1 & dummy_out==1 [w=weight], d
	local  Kur_Dx_nc=(r(Var)+r(mean)^2)/(r(mean)^2)
	qui drop var_aux
	
	* Cross moments of the joint distribution of (capital gap changes, tau)
	qui gen Cross_moment=(Delta_x-`mean_Dx')*(tau-`mean_tau') if dummy_tau==1 & dummy_bal==1 & dummy_out==1

	qui sum Cross_moment [w=weight],d
	local  cov_Dxtau=r(mean)			// Cov[tau, \Delta x]
	matrix col_n= [col_n, `cov_Dxtau']
	
	local hat_x=`mean_Dx'/2*(1-`CV_tau')+`cov_Dxtau'/`mean_tau'
 
	qui gen x_tau1=(`hat_x'-Delta_x)  if dummy_tau==1 & dummy_bal==1 & dummy_out==1 // Generate x_tau = (x^* - Delta x)

	qui gen var_aux=x_tau1^3  
	qui sum var_aux [w=weight]  
	local  m3_xt=r(mean)				// E[ x_tau^3 ]
	qui drop var_aux
	matrix col_n= [col_n, `m3_xt']
	
	qui gen var_aux=tau*x_tau1^2 
	qui sum var_aux  [w=weight]
	qui local  m12_txt=r(mean)			// E[ tau * x_tau^2 ]
	qui drop var_aux
	matrix col_n= [col_n, `m12_txt']
	
	* Outputs from theory
	local nu    =`mean_Dx'/`mean_tau'
	local sigma2=`m2_Dx'/`mean_tau'-`nu'*2*`hat_x'

	local m2_xt  =((`hat_x')^3-`m3_xt')/(`mean_Dx'*3)+(`sigma2'*2/(2*`nu'))*0                    // E[x^2]
	local m0_xta =`mean_tau'/2*(1+`CV_tau')                                                      // E[a]
	local m1_xta =-`m12_txt'/(`nu'*2*`mean_tau')+`m2_xt'/(`nu'*2)+(`sigma2'*1/(2*`nu'))*`m0_xta' // E[x a]

	local check1 =`m2_xt'/(`sigma2')          // 1st term of CIR:   Var[x] / sigma^2
	local check2 =(`nu'*`m1_xta')/(`sigma2')  // 2nd term of CIR:   nu*Cov[a, x] / sigma^2
	local check3 =`check1'+`check2' 		  // CIR, asymmetric + drift
	local check4 =`mean_tau'*`Kur_Dx_c'/6     // CIR, symmetric + driftless
	local check5 =`mean_tau'*`Kur_Dx_nc'/6	  // CIR, symmetric + drifless, use uncentralized kurtosis
	
	matrix col_n= [col_n, `nu', `sigma2', `hat_x', `m2_xt', `m1_xta', `check1', `check2', `check3',`var_aux_check1' ,`var_aux_check2',`Kur_Dx_c',`Kur_Dx_nc',`check4',`check5']
	
 	
	drop dummy_tau Cross_moment x_tau1
	
	if `index_i'==1{
		matrix sample_total=col_n
	}
	else if `index_i'>1{
		matrix sample_total=[sample_total \col_n] // add other bootstrap samples as rows to same matrix
	}
}
 
*
clear 

* Turn bootstrap samples back into variables, and save mean and quantiles of each statistic
qui svmat double sample_total, name(sample_n)

* mean tau 
qui sum sample_n1,d
qui putexcel B3=(`r(mean)')
qui putexcel C3=(`r(p10)')
qui putexcel D3=(`r(p50)')
qui putexcel E3=(`r(p90)')
 
* mean tau^2 
qui sum sample_n2,d
qui putexcel B4=(`r(mean)')
qui putexcel C4=(`r(p10)')
qui putexcel D4=(`r(p50)')
qui putexcel E4=(`r(p90)')

* mean std(tau) 
sum sample_n3,d
qui putexcel B5=(`r(mean)')
qui putexcel C5=(`r(p10)')
qui putexcel D5=(`r(p50)')
qui putexcel E5=(`r(p90)')

* mean CV(tau) 
qui sum sample_n4,d
qui putexcel B6=(`r(mean)')
qui putexcel C6=(`r(p10)')
qui putexcel D6=(`r(p50)')
qui putexcel E6=(`r(p90)')


* mean Delta x 
qui sum sample_n5,d
qui putexcel B7=(`r(mean)')
qui putexcel C7=(`r(p10)')
qui putexcel D7=(`r(p50)')
qui putexcel E7=(`r(p90)')


* mean  Delta x^2 
qui sum sample_n6,d
qui putexcel B8=(`r(mean)')
qui putexcel C8=(`r(p10)')
qui putexcel D8=(`r(p50)')
qui putexcel E8=(`r(p90)')

* Cov  Delta x,tau 
qui sum sample_n7,d
qui putexcel B9=(`r(mean)')
qui putexcel C9=(`r(p10)')
qui putexcel D9=(`r(p50)')
qui putexcel E9=(`r(p90)')

* mean  (hat(x)-Delta x)^3 
qui sum sample_n8,d
qui putexcel B10=(`r(mean)')
qui putexcel C10=(`r(p10)')
qui putexcel D10=(`r(p50)')
qui putexcel E10=(`r(p90)')

* mean  tau (hat(x)-Delta x)^2 
sum sample_n9,d
qui putexcel B11=(`r(mean)')
qui putexcel C11=(`r(p10)')
qui putexcel D11=(`r(p50)')
qui putexcel E11=(`r(p90)')
 
* parameter nu 
qui sum sample_n10,d
qui putexcel B14=(`r(mean)')
qui putexcel C14=(`r(p10)')
qui putexcel D14=(`r(p50)')
qui putexcel E14=(`r(p90)')

* parameter sigma^2 
qui sum sample_n11,d
qui putexcel B15=(`r(mean)')
qui putexcel C15=(`r(p10)')
qui putexcel D15=(`r(p50)')
qui putexcel E15=(`r(p90)')

* parameter hat(x) 
qui sum sample_n12,d
qui putexcel B16=(`r(mean)')
qui putexcel C16=(`r(p10)')
qui putexcel D16=(`r(p50)')
qui putexcel E16=(`r(p90)')

* moment: M2[x]
qui sum sample_n13,d
qui putexcel B17=(`r(mean)')
qui putexcel C17=(`r(p10)')
qui putexcel D17=(`r(p50)')
qui putexcel E17=(`r(p90)')


* moment: M11[x,a] 
qui sum sample_n14,d
qui putexcel B18=(`r(mean)')
qui putexcel C18=(`r(p10)')
qui putexcel D18=(`r(p50)')
qui putexcel E18=(`r(p90)')


* CIR 1:  M2[x]/sigma^2 
qui sum sample_n15,d
qui putexcel B19=(`r(mean)')
qui putexcel C19=(`r(p10)')
qui putexcel D19=(`r(p50)')
qui putexcel E19=(`r(p90)') 

* CIR 2:  -nu*M11[x,a]/sigma^2 
qui sum sample_n16,d
qui putexcel B20=(`r(mean)')
qui putexcel C20=(`r(p10)')
qui putexcel D20=(`r(p50)')
qui putexcel E20=(`r(p90)') 

* CIR :  M2[x]/sigma^2-nu/sigma^2 m11[x,a]
qui sum sample_n17,d
qui putexcel B21=(`r(mean)')
qui putexcel C21=(`r(p10)')
qui putexcel D21=(`r(p50)')
qui putexcel E21=(`r(p90)') 

* check 1:   
qui sum sample_n18,d
qui putexcel B24=(`r(mean)')
qui putexcel C24=(`r(p10)')
qui putexcel D24=(`r(p50)')
qui putexcel E24=(`r(p90)')

*  check 2:  
qui sum sample_n19,d
qui putexcel B25=(`r(mean)')
qui putexcel C25=(`r(p10)')
qui putexcel D25=(`r(p50)')
qui putexcel E25=(`r(p90)')
 
* Centralized kurtosis  
qui sum sample_n20,d
qui putexcel E33=(`r(mean)')
qui putexcel F33=(`r(p10)')
qui putexcel G33=(`r(p50)')
qui putexcel H33=(`r(p90)')
 
* Non-centralized kurtosis  
qui sum sample_n21,d
qui putexcel E34=(`r(mean)')
qui putexcel F34=(`r(p10)')
qui putexcel G34=(`r(p50)')
qui putexcel H34=(`r(p90)')

* Centralized kurtosis  
qui sum sample_n22,d
qui putexcel E35=(`r(mean)')
qui putexcel F35=(`r(p10)')
qui putexcel G35=(`r(p50)')
qui putexcel H35=(`r(p90)')

* Centralized kurtosis  
qui sum sample_n23,d
qui putexcel E36=(`r(mean)')
qui putexcel F36=(`r(p10)')
qui putexcel G36=(`r(p50)')
qui putexcel H36=(`r(p90)')
 
