

* Aggregate Dynamics in Lumpy Economies
* by Isaac Baley and Andres Blanco
* ECONOMETRICA, 2020

/* This code produces the information for Table I: Inputs from Data and Outputs from Theory

 - Reads directly the clean data that contains a panel of observables (Delta x, tau)
 
 - Specifications: 
	.... Chilean Annual Industrial Survey (ENIA) 
	.... Firms with more than 10 years of data
	.... Only one stopping time per firm
	.... All firm sizes
	.... All sectors
	.... Without firm weights
	.... Eliminates outliers above 98th and below 2nd percentile
	.... Inaction threshold of 1%
	.... Non-zero gap changes
	
 - Computes a variety of statistics in the data and applies the formulas to recover parameters, ergodic moments and CIR 
 
 - Saves the data for the figure on a .csv file 
 
*/

* Set country
global fileg "CHILE"

* Baseline specification in main text
global balance_panel  = 1		// Balanced panel only
global outliers       = 2 
global Tauclean		  = 1       // Keep 1 stopping time per firm
global years_da       = 10		// Keep firms with 10 or more years of data	  

* Choose sample
global  FirmType      ="all"	// All firms
global  WeightFirm    ="no"		// Unweighted
global  SectorType    ="all"	// All sectors

local   CapitalTypeList  build total   // Capital types: buildings, total

* Run main program for the two capital types
foreach CapitalType of local CapitalTypeList { 	// loop over capital types
	global CapitalType = "`CapitalType'" 
	di "Computing inputs from data/outputs from theory ... $fileg, $CapitalType, firm size: $FirmType"
	qui do "MainProg.do"
}
