function M = inaction_moments(m,p,model_type,lambda,SS,objective_func)

% Generate the grid 
        
x_grid      = linspace(SS.x_hat_lb,SS.x_hat_ub,p.N)';
Deltah      = x_grid(2)-x_grid(1);

% Index for optimal reset capital

indices     = (1:1:p.N)';
indices_d   = [1;indices(1:end-1)];
[~,ind_ast] = min(abs(x_grid-SS.x_hat_ast));

% Generate the finite difference hazard

switch  model_type
            
	case 'Fin_diff_Ber'
    
       	LAMBDA =repmat(lambda,p.N,1);
        
	case 'Fin_diff_ExtBer'
                 
        LAMBDA =lambda*(x_grid<SS.x_hat_ast);     
                
end
 
% Transition probability: HBJ
A              =    sparse(indices  ,indices  ,              +p.sigma^2/Deltah^2+LAMBDA,p.N,p.N);
A              = A +sparse(indices  ,indices_d,-p.nu/Deltah/2-p.sigma^2/Deltah^2/2     ,p.N,p.N);
A        	   = A +sparse(indices_d,indices  , p.nu/Deltah/2-p.sigma^2/Deltah^2/2     ,p.N,p.N);    

A(1,:)         = 0;
A(end,:)       = 0;

A(1,1)         = 1;
A(end,end)     = 1;

switch  objective_func
            
	case 'expectation'
    
       	f              =x_grid.^m;
        f(1)           =0;
        f(end)         =0;
        
	case 'profits'
                 
        f              =exp(p.alpha*x_grid);    
        f(1)           =0;
        f(end)         =0;

    case 'freq_up'
                 
        f              =x_grid*0;    
        f(1)           =0;
        f(end)         =1;      
        
    case 'freq_down'
                 
        f              =x_grid*0;    
        f(1)           =1;
        f(end)         =0;     
        
end

% Solution of HBJ

v_0            =A\f;    
        
% Apply Lagrange Interpolation formula for v_0

x_1       =x_grid(ind_ast-1);
x_2       =x_grid(ind_ast);
x_3       =x_grid(ind_ast+1);

fx_1      =v_0(ind_ast-1);
fx_2      =v_0(ind_ast);
fx_3      =v_0(ind_ast+1);

v_0_ast   =(SS.x_hat_ast-x_2)*(SS.x_hat_ast-x_3)/(x_1-x_2)/(x_1-x_3)*fx_1+...
           (SS.x_hat_ast-x_1)*(SS.x_hat_ast-x_3)/(x_2-x_1)/(x_2-x_3)*fx_2+...
           (SS.x_hat_ast-x_1)*(SS.x_hat_ast-x_2)/(x_3-x_1)/(x_3-x_2)*fx_3;
                 
M         =v_0_ast;


return